/*
 * xmem.c
 * Thomas Nemeth -- le 24 aot 2001
 *
 *   Copyright (C) 1999  Thomas Nemeth
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <strings.h>
#include "xmem.h"


void *xmalloc(size_t size)
{
        void *ret = malloc(size);
        if (! ret)
        {
                perror("malloc() ");
                exit(-1);
        }
        else
        {
                return ret;
        }
}


char *xstrdup(const char *string)
{
        char *ret = strdup(string);
        if (! ret)
        {
                perror("strdup() ");
                exit(-1);
        }
        else
        {
                return ret;
        }
}
